# LlamaIndex Embeddings Integration: Upstage

[Upstage](https://www.upstage.ai/) is a leading artificial intelligence (AI) company specializing in delivering above-human-grade performance LLM components.

## Solar Embeddings

The embeddings API converts text into numbers that computers can understand. Imagine converting a sentence into a list of numbers, each capturing a piece of the sentence's meaning. This makes it easier for machines to do tasks like finding similar texts, sorting information, or even answering questions.

Check more details [here](https://developers.upstage.ai/docs/apis/embeddings).
